@@ -24,6 +24,7 @@ from eva.catalog.services.df_column_service import DatasetColumnService
 from eva.catalog.services.df_service import DatasetService
 from eva.catalog.services.udf_io_service import UdfIOService
 from eva.catalog.services.udf_service import UdfService
+from eva.parser.create_statement import ColConstraintInfo
 from eva.parser.table_ref import TableInfo
 from eva.utils.logging_manager import logger
 
@@ -110,6 +111,7 @@ class CatalogManager(object):
         data_type: ColumnType,
         array_type: NdArrayType,
         dimensions: List[int],
+        cci: ColConstraintInfo,
     ) -> DataFrameColumn:
         """Create a dataframe column object this column.
         This function won't commit this object in the catalog database.
@@ -127,6 +129,7 @@ class CatalogManager(object):
             data_type,
             array_type=array_type,
             array_dimensions=dimensions,
+            is_nullable=cci.nullable,
         )
 
     def get_dataset_metadata(
