@@ -12,7 +12,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Iterator
+from typing import Generator, Iterator
 
 from eva.executor.abstract_executor import AbstractExecutor
 from eva.executor.executor_utils import apply_predicate, apply_project
@@ -32,17 +32,14 @@ class LateralJoinExecutor(AbstractExecutor):
     def exec(self, *args, **kwargs) -> Iterator[Batch]:
         outer = self.children[0]
         inner = self.children[1]
-        for outer_batch in outer.exec():
+        for outer_batch in outer.exec(**kwargs):
             for result_batch in inner.exec(lateral_input=outer_batch):
-                result_batch = outer_batch.frames.merge(
-                    result_batch.frames,
-                    left_index=True,
-                    right_index=True,
-                    how="inner",
-                )
-                result_batch.reset_index(drop=True, inplace=True)
-                result_batch = Batch(result_batch)
+                result_batch = Batch.join(outer_batch, result_batch)
+                result_batch.reset_index()
                 result_batch = apply_predicate(result_batch, self.predicate)
                 result_batch = apply_project(result_batch, self.join_project)
                 if not result_batch.empty():
                     yield result_batch
+
+    def __call__(self, *args, **kwargs) -> Generator[Batch, None, None]:
+        yield from self.exec(*args, **kwargs)
