@@ -46,3 +46,7 @@ class LimitExecutor(AbstractExecutor):
 
             remaining_tuples -= len(batch)
             yield batch
+
+            if remaining_tuples <= 0:
+                assert remaining_tuples == 0
+                return
