@@ -12,30 +12,16 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import json
-from typing import Iterable, List, TypeVar, Union
+from typing import Callable, Iterable, List, TypeVar, Union
 
 import numpy as np
 import pandas as pd
 
+from eva.expression.abstract_expression import ExpressionType
 from eva.parser.alias import Alias
+from eva.utils.generic_utils import PickleSerializer
 from eva.utils.logging_manager import logger
 
-
-class BatchEncoder(json.JSONEncoder):
-    def default(self, obj):
-        if isinstance(obj, pd.DataFrame):
-            return {"__dataframe__": obj.to_json()}
-        return json.JSONEncoder.default(self, obj)
-
-
-def as_batch(d):
-    if "__dataframe__" in d:
-        return pd.read_json(d["__dataframe__"])
-    else:
-        return d
-
-
 Batch = TypeVar("Batch")
 
 
@@ -49,16 +35,14 @@ class Batch:
 
     Arguments:
         frames (DataFrame): pandas Dataframe holding frames data
-        identifier_column (str): A column used to uniquely a row
     """
 
-    def __init__(self, frames=None, identifier_column=None):
+    def __init__(self, frames=None):
         self._frames = pd.DataFrame() if frames is None else frames
         if not isinstance(self._frames, pd.DataFrame):
             raise ValueError(
                 "Batch constructor not properly called.\n" "Expected pandas.DataFrame"
             )
-        self._identifier_column = identifier_column
 
     @property
     def frames(self) -> pd.DataFrame:
@@ -74,31 +58,82 @@ class Batch:
     def column_as_numpy_array(self, column_name="data"):
         return np.array(self._frames[column_name])
 
-    def to_json(self):
-        obj = {
-            "frames": self.frames,
-            "batch_size": len(self),
-            "identifier_column": self._identifier_column,
-        }
-        return json.dumps(obj, cls=BatchEncoder)
+    def serialize(self):
+        obj = {"frames": self._frames, "batch_size": len(self)}
+        return PickleSerializer.serialize(obj)
 
     @classmethod
-    def from_json(cls, json_str: str):
-        obj = json.loads(json_str, object_hook=as_batch)
-        return cls(frames=obj["frames"], identifier_column=obj["identifier_column"])
+    def deserialize(cls, data):
+        obj = PickleSerializer.deserialize(data)
+        return cls(frames=obj["frames"])
 
-    def __str__(self) -> str:
-        return (
-            "Batch Object:\n"
-            "@dataframe: %s\n"
-            "@batch_size: %d\n"
-            "@identifier_column: %s"
-            % (self._frames, len(self), self._identifier_column)
+    @classmethod
+    def from_eq(cls, batch1: Batch, batch2: Batch) -> Batch:
+        return Batch(
+            pd.DataFrame(batch1._frames.to_numpy() == batch2._frames.to_numpy())
         )
 
+    @classmethod
+    def from_greater(cls, batch1: Batch, batch2: Batch) -> Batch:
+        return Batch(
+            pd.DataFrame(batch1._frames.to_numpy() > batch2._frames.to_numpy())
+        )
+
+    @classmethod
+    def from_lesser(cls, batch1: Batch, batch2: Batch) -> Batch:
+        return Batch(
+            pd.DataFrame(batch1._frames.to_numpy() < batch2._frames.to_numpy())
+        )
+
+    @classmethod
+    def from_greater_eq(cls, batch1: Batch, batch2: Batch) -> Batch:
+        return Batch(
+            pd.DataFrame(batch1._frames.to_numpy() >= batch2._frames.to_numpy())
+        )
+
+    @classmethod
+    def from_lesser_eq(cls, batch1: Batch, batch2: Batch) -> Batch:
+        return Batch(
+            pd.DataFrame(batch1._frames.to_numpy() <= batch2._frames.to_numpy())
+        )
+
+    @classmethod
+    def from_not_eq(cls, batch1: Batch, batch2: Batch) -> Batch:
+        return Batch(
+            pd.DataFrame(batch1._frames.to_numpy() != batch2._frames.to_numpy())
+        )
+
+    @classmethod
+    def compare_contains(cls, batch1: Batch, batch2: Batch) -> None:
+        return cls(
+            pd.DataFrame(
+                [all(x in p for x in q) for p, q in zip(left, right)]
+                for left, right in zip(
+                    batch1._frames.to_numpy(), batch2._frames.to_numpy()
+                )
+            )
+        )
+
+    @classmethod
+    def compare_is_contained(cls, batch1: Batch, batch2: Batch) -> None:
+        return cls(
+            pd.DataFrame(
+                [all(x in q for x in p) for p, q in zip(left, right)]
+                for left, right in zip(
+                    batch1._frames.to_numpy(), batch2._frames.to_numpy()
+                )
+            )
+        )
+
+    def __str__(self) -> str:
+        with pd.option_context(
+            "display.pprint_nest_depth", 1, "display.max_colwidth", 100
+        ):
+            return f"{self._frames}"
+
     def __eq__(self, other: Batch):
-        return self.frames[sorted(self.frames.columns)].equals(
-            other.frames[sorted(other.frames.columns)]
+        return self._frames[sorted(self.columns)].equals(
+            other.frames[sorted(other.columns)]
         )
 
     def __getitem__(self, indices) -> Batch:
@@ -117,7 +152,7 @@ class Batch:
             start = indices.start if indices.start else 0
             end = indices.stop if indices.stop else len(self.frames)
             if end < 0:
-                end = len(self.frames) + end
+                end = len(self._frames) + end
             step = indices.step if indices.step else 1
             return self._get_frames_from_indices(range(start, end, step))
         elif isinstance(indices, int):
@@ -126,19 +161,23 @@ class Batch:
             raise TypeError("Invalid argument type: {}".format(type(indices)))
 
     def _get_frames_from_indices(self, required_frame_ids):
-        new_frames = self.frames.iloc[required_frame_ids, :]
+        new_frames = self._frames.iloc[required_frame_ids, :]
         new_batch = Batch(new_frames)
         return new_batch
 
+    def apply_function_expression(self, expr: Callable) -> None:
+        """
+        Execute function expression on frames.
+        """
+        self._frames = expr(self._frames)
+
     def sort(self, by=None) -> None:
         """
         in_place sort
         """
         if by is None:
-            if self._identifier_column in self._frames:
-                by = [self._identifier_column]
-            elif not self.empty():
-                by = self.frames.columns[0]
+            if not self.empty():
+                by = self.columns[0]
             else:
                 logger.warn("Sorting an empty batch")
                 return
@@ -153,8 +192,6 @@ class Batch:
             sort_type: list of True/False if ASC for each column name in 'by'
                 i.e [True, False] means [ASC, DESC]
         """
-        # if by is None and self.identifier_column in self._frames:
-        #     by = [self.identifier_column]
 
         if sort_type is None:
             sort_type = [True]
@@ -175,6 +212,32 @@ class Batch:
         else:
             logger.warn("Columns and Sort Type are required for orderby")
 
+    def invert(self) -> None:
+        self._frames = ~self._frames
+
+    def all_true(self) -> bool:
+        return self._frames.all().bool()
+
+    def all_false(self) -> bool:
+        inverted = ~self._frames
+        return inverted.all().bool()
+
+    def create_mask(self) -> List:
+        """
+        Return list of indices of first row.
+        """
+        return self._frames[self._frames[0]].index.tolist()
+
+    def create_inverted_mask(self) -> List:
+        return self._frames[~self._frames[0]].index.tolist()
+
+    def update_indices(self, indices: List, other: Batch):
+        self._frames.iloc[indices] = other._frames
+        self._frames = pd.DataFrame(self._frames)
+
+    def video_file_paths(self) -> Iterable:
+        yield from self._frames["video_file_path"]
+
     def project(self, cols: None) -> Batch:
         """
         Takes as input the column list, returns the projection.
@@ -189,7 +252,16 @@ class Batch:
                                  Frames: %s"
                 % (unknown_cols, self._frames)
             )
-        return Batch(self._frames[verfied_cols], self._identifier_column)
+        return Batch(self._frames[verfied_cols])
+
+    def repeat(self, times: int) -> None:
+        """
+        Repeat the rows of a dataframe.
+
+        Arguments:
+            times: number of times to repeat
+        """
+        self._frames = pd.DataFrame(np.repeat(self._frames.to_numpy(), times, axis=0))
 
     @classmethod
     def merge_column_wise(cls, batches: List[Batch], auto_renaming=False) -> Batch:
@@ -229,7 +301,7 @@ class Batch:
         if other.empty():
             return self
 
-        new_frames = self.frames.append(other.frames, ignore_index=True)
+        new_frames = self._frames.append(other.frames, ignore_index=True)
 
         return Batch(new_frames)
 
@@ -249,6 +321,65 @@ class Batch:
 
         return Batch(frame)
 
+    @classmethod
+    def stack(cls, batch: Batch, copy=True) -> Batch:
+        """Stack a given batch along the 0th dimension.
+        Notice: input assumed to contain only one column with video frames
+
+        Returns:
+            Batch (always of length 1)
+        """
+        if len(batch.columns) > 1:
+            raise ValueError("Stack can only be called on single-column batches")
+        frame_data_col = batch.columns[0]
+
+        stacked_array = np.array(batch.frames[frame_data_col].values.tolist())
+        stacked_frame = pd.DataFrame([{frame_data_col: stacked_array}])
+
+        return Batch(stacked_frame)
+
+    @classmethod
+    def join(cls, first: Batch, second: Batch, how="inner") -> Batch:
+        return cls(
+            first._frames.merge(
+                second._frames, left_index=True, right_index=True, how=how
+            )
+        )
+
+    @classmethod
+    def combine_batches(
+        cls, first: Batch, second: Batch, expression: ExpressionType
+    ) -> Batch:
+        """
+        Creates Batch by combining two batches using some arithmetic expression.
+        """
+        if expression == ExpressionType.ARITHMETIC_ADD:
+            return Batch(pd.DataFrame(first._frames + second._frames))
+        elif expression == ExpressionType.ARITHMETIC_SUBTRACT:
+            return Batch(pd.DataFrame(first._frames - second._frames))
+        elif expression == ExpressionType.ARITHMETIC_MULTIPLY:
+            return Batch(pd.DataFrame(first._frames * second._frames))
+        elif expression == ExpressionType.ARITHMETIC_DIVIDE:
+            return Batch(pd.DataFrame(first._frames / second._frames))
+
+    def reassign_indices_to_hash(self, indices) -> None:
+        """
+        Hash indices and replace the indices with those hash values.
+        """
+        self._frames.index = self._frames[indices].apply(
+            lambda x: hash(tuple(x)), axis=1
+        )
+
+    def aggregate(self, method: str) -> None:
+        """
+        Aggregate batch based on method.
+        Methods can be sum, count, min, max, mean
+
+        Arguments:
+            method: string with one of the five above options
+        """
+        self._frames = self._frames.agg([method])
+
     def empty(self):
         """Checks if the batch is empty
         Returns:
@@ -256,11 +387,22 @@ class Batch:
         """
         return len(self) == 0
 
+    def unnest(self) -> None:
+        """
+        Unnest columns and drop columns with no data
+        """
+        self._frames = self._frames.explode(list(self._frames.columns))
+        self._frames.dropna(inplace=True)
+
     def reverse(self) -> None:
         """Reverses dataframe"""
         self._frames = self._frames[::-1]
         self._frames.reset_index(drop=True, inplace=True)
 
+    def drop_zero(self, outcomes: Batch) -> None:
+        """Drop all columns with corresponding outcomes containing zero."""
+        self._frames = self._frames[(outcomes._frames > 0).to_numpy()]
+
     def reset_index(self):
         """Resets the index of the data frame in the batch"""
         self._frames.reset_index(drop=True, inplace=True)
@@ -272,10 +414,10 @@ class Batch:
             alias = Alias(alias)
         new_col_names = []
         if len(alias.col_names):
-            if len(self.frames.columns) != len(alias.col_names):
+            if len(self.columns) != len(alias.col_names):
                 err_msg = (
                     f"Expected {len(alias.col_names)} columns {alias.col_names},"
-                    f"got {len(self.frames.columns)} columns {self.frames.columns}."
+                    f"got {len(self.columns)} columns {self.columns}."
                 )
                 logger.error(err_msg)
                 raise RuntimeError(err_msg)
@@ -284,7 +426,7 @@ class Batch:
                 for col_name in alias.col_names
             ]
         else:
-            for col_name in self.frames.columns:
+            for col_name in self.columns:
                 if "." in col_name:
                     new_col_names.append(
                         "{}.{}".format(alias.alias_name, col_name.split(".")[1])
@@ -292,15 +434,15 @@ class Batch:
                 else:
                     new_col_names.append("{}.{}".format(alias.alias_name, col_name))
 
-        self.frames.columns = new_col_names
+        self._frames.columns = new_col_names
 
     def drop_column_alias(self) -> None:
         # table1.a, table1.b, table1.c -> a, b, c
         new_col_names = []
-        for col_name in self.frames.columns:
+        for col_name in self.columns:
             if "." in col_name:
                 new_col_names.append(col_name.split(".")[1])
             else:
                 new_col_names.append(col_name)
 
-        self.frames.columns = new_col_names
+        self._frames.columns = new_col_names
