@@ -33,6 +33,7 @@ class OperatorType(IntEnum):
     """
 
     DUMMY = auto()
+    LOGICALEXCHANGE = auto()
     LOGICALGET = auto()
     LOGICALFILTER = auto()
     LOGICALPROJECT = auto()
@@ -45,6 +46,7 @@ class OperatorType(IntEnum):
     LOGICALUPLOAD = auto()
     LOGICALQUERYDERIVEDGET = auto()
     LOGICALUNION = auto()
+    LOGICALGROUPBY = auto()
     LOGICALORDERBY = auto()
     LOGICALLIMIT = auto()
     LOGICALSAMPLE = auto()
@@ -53,6 +55,7 @@ class OperatorType(IntEnum):
     LOGICAL_CREATE_MATERIALIZED_VIEW = auto()
     LOGICAL_SHOW = auto()
     LOGICALDROPUDF = auto()
+    LOGICALEXPLAIN = auto()
     LOGICALDELIMITER = auto()
 
 
@@ -142,6 +145,7 @@ class LogicalGet(Operator):
         alias: str,
         predicate: AbstractExpression = None,
         target_list: List[AbstractExpression] = None,
+        sampling_rate: int = None,
         children=None,
     ):
         self._video = video
@@ -149,6 +153,7 @@ class LogicalGet(Operator):
         self._alias = alias
         self._predicate = predicate
         self._target_list = target_list
+        self._sampling_rate = sampling_rate
         super().__init__(OperatorType.LOGICALGET, children)
 
     @property
@@ -179,6 +184,10 @@ class LogicalGet(Operator):
     def target_list(self, target_list):
         self._target_list = target_list
 
+    @property
+    def sampling_rate(self):
+        return self._sampling_rate
+
     def __eq__(self, other):
         is_subtree_equal = super().__eq__(other)
         if not isinstance(other, LogicalGet):
@@ -190,6 +199,7 @@ class LogicalGet(Operator):
             and self.alias == other.alias
             and self.predicate == other.predicate
             and self.target_list == other.target_list
+            and self.sampling_rate == other.sampling_rate
         )
 
     def __hash__(self) -> int:
@@ -201,6 +211,7 @@ class LogicalGet(Operator):
                 self.dataset_metadata,
                 self.predicate,
                 tuple(self.target_list or []),
+                self.sampling_rate,
             )
         )
 
@@ -282,6 +293,25 @@ class LogicalProject(Operator):
         return hash((super().__hash__(), tuple(self.target_list)))
 
 
+class LogicalGroupBy(Operator):
+    def __init__(self, groupby_clause: ConstantValueExpression, children: List = None):
+        super().__init__(OperatorType.LOGICALGROUPBY, children)
+        self._groupby_clause = groupby_clause
+
+    @property
+    def groupby_clause(self):
+        return self._groupby_clause
+
+    def __eq__(self, other):
+        is_subtree_equal = super().__eq__(other)
+        if not isinstance(other, LogicalGroupBy):
+            return False
+        return is_subtree_equal and self.groupby_clause == other.groupby_clause
+
+    def __hash__(self) -> int:
+        return hash((super().__hash__(), self.groupby_clause))
+
+
 class LogicalOrderBy(Operator):
     def __init__(self, orderby_list: List, children: List = None):
         super().__init__(OperatorType.LOGICALORDERBY, children)
@@ -1035,3 +1065,36 @@ class LogicalShow(Operator):
 
     def __hash__(self) -> int:
         return hash((super().__hash__(), self.show_type))
+
+
+class LogicalExchange(Operator):
+    def __init__(self, children=None):
+        super().__init__(OperatorType.LOGICALEXCHANGE, children)
+
+    def __eq__(self, other):
+        if not isinstance(other, LogicalExchange):
+            return False
+        return True
+
+    def __hash__(self) -> int:
+        return super().__hash__()
+
+
+class LogicalExplain(Operator):
+    def __init__(self, children: List = None):
+        super().__init__(OperatorType.LOGICALEXPLAIN, children)
+        assert len(children) == 1, "EXPLAIN command only takes one child"
+        self._explainable_opr = children[0]
+
+    @property
+    def explainable_opr(self):
+        return self._explainable_opr
+
+    def __eq__(self, other):
+        is_subtree_equal = super().__eq__(other)
+        if not isinstance(other, LogicalExplain):
+            return False
+        return is_subtree_equal and self._explainable_opr == other.explainable_opr
+
+    def __hash__(self) -> int:
+        return hash((super().__hash__(), self._explainable_opr))
