@@ -14,8 +14,6 @@
 # limitations under the License.
 from __future__ import annotations
 
-from abc import ABC, abstractmethod
-from enum import Flag, IntEnum, auto
 from typing import TYPE_CHECKING
 
 from eva.expression.expression_utils import conjuction_list_to_expression_tree
@@ -25,8 +23,10 @@ from eva.optimizer.optimizer_utils import (
     extract_pushdown_predicate_for_alias,
 )
 from eva.optimizer.rules.pattern import Pattern
+from eva.optimizer.rules.rules_base import Promise, Rule, RuleType
 from eva.parser.types import JoinType
 from eva.planner.create_mat_view_plan import CreateMaterializedViewPlan
+from eva.planner.explain_plan import ExplainPlan
 from eva.planner.hash_join_build_plan import HashJoinBuildPlan
 from eva.planner.predicate_plan import PredicatePlan
 from eva.planner.project_plan import ProjectPlan
@@ -43,9 +43,11 @@ from eva.optimizer.operators import (
     LogicalCreateUDF,
     LogicalDrop,
     LogicalDropUDF,
+    LogicalExplain,
     LogicalFilter,
     LogicalFunctionScan,
     LogicalGet,
+    LogicalGroupBy,
     LogicalInsert,
     LogicalJoin,
     LogicalLimit,
@@ -66,6 +68,7 @@ from eva.planner.create_udf_plan import CreateUDFPlan
 from eva.planner.drop_plan import DropPlan
 from eva.planner.drop_udf_plan import DropUDFPlan
 from eva.planner.function_scan_plan import FunctionScanPlan
+from eva.planner.groupby_plan import GroupByPlan
 from eva.planner.hash_join_probe_plan import HashJoinProbePlan
 from eva.planner.insert_plan import InsertPlan
 from eva.planner.lateral_join_plan import LateralJoinPlan
@@ -79,159 +82,6 @@ from eva.planner.storage_plan import StoragePlan
 from eva.planner.union_plan import UnionPlan
 from eva.planner.upload_plan import UploadPlan
 
-# Modified
-
-
-class RuleType(Flag):
-    """
-    Manages enums for all the supported rules
-    """
-
-    # Don't move this enum, else will break rule exploration logic
-    INVALID_RULE = 0
-
-    # REWRITE RULES(LOGICAL -> LOGICAL)
-    EMBED_FILTER_INTO_GET = auto()
-    EMBED_FILTER_INTO_DERIVED_GET = auto()
-    PUSHDOWN_FILTER_THROUGH_SAMPLE = auto()
-    PUSHDOWN_PROJECT_THROUGH_SAMPLE = auto()
-    EMBED_PROJECT_INTO_DERIVED_GET = auto()
-    EMBED_PROJECT_INTO_GET = auto()
-    PUSHDOWN_FILTER_THROUGH_JOIN = auto()
-    REWRITE_DELIMETER = auto()
-
-    # TRANSFORMATION RULES (LOGICAL -> LOGICAL)
-    LOGICAL_INNER_JOIN_COMMUTATIVITY = auto()
-    TRANSFORMATION_DELIMETER = auto()
-
-    # IMPLEMENTATION RULES (LOGICAL -> PHYSICAL)
-    LOGICAL_UNION_TO_PHYSICAL = auto()
-    LOGICAL_ORDERBY_TO_PHYSICAL = auto()
-    LOGICAL_LIMIT_TO_PHYSICAL = auto()
-    LOGICAL_INSERT_TO_PHYSICAL = auto()
-    LOGICAL_LOAD_TO_PHYSICAL = auto()
-    LOGICAL_UPLOAD_TO_PHYSICAL = auto()
-    LOGICAL_CREATE_TO_PHYSICAL = auto()
-    LOGICAL_RENAME_TO_PHYSICAL = auto()
-    LOGICAL_DROP_TO_PHYSICAL = auto()
-    LOGICAL_CREATE_UDF_TO_PHYSICAL = auto()
-    LOGICAL_MATERIALIZED_VIEW_TO_PHYSICAL = auto()
-    LOGICAL_GET_TO_SEQSCAN = auto()
-    LOGICAL_SAMPLE_TO_UNIFORMSAMPLE = auto()
-    LOGICAL_DERIVED_GET_TO_PHYSICAL = auto()
-    LOGICAL_LATERAL_JOIN_TO_PHYSICAL = auto()
-    LOGICAL_JOIN_TO_PHYSICAL_HASH_JOIN = auto()
-    LOGICAL_FUNCTION_SCAN_TO_PHYSICAL = auto()
-    LOGICAL_FILTER_TO_PHYSICAL = auto()
-    LOGICAL_PROJECT_TO_PHYSICAL = auto()
-    LOGICAL_SHOW_TO_PHYSICAL = auto()
-    LOGICAL_DROP_UDF_TO_PHYSICAL = auto()
-    IMPLEMENTATION_DELIMETER = auto()
-
-    NUM_RULES = auto()
-
-
-class Promise(IntEnum):
-    """
-    Manages order in which rules should be applied.
-    Rule with a higher enum will be preferred in case of
-    conflict
-    """
-
-    # IMPLEMENTATION RULES
-    LOGICAL_UNION_TO_PHYSICAL = auto()
-    LOGICAL_MATERIALIZED_VIEW_TO_PHYSICAL = auto()
-    LOGICAL_ORDERBY_TO_PHYSICAL = auto()
-    LOGICAL_LIMIT_TO_PHYSICAL = auto()
-    LOGICAL_INSERT_TO_PHYSICAL = auto()
-    LOGICAL_RENAME_TO_PHYSICAL = auto()
-    LOGICAL_DROP_TO_PHYSICAL = auto()
-    LOGICAL_LOAD_TO_PHYSICAL = auto()
-    LOGICAL_UPLOAD_TO_PHYSICAL = auto()
-    LOGICAL_CREATE_TO_PHYSICAL = auto()
-    LOGICAL_CREATE_UDF_TO_PHYSICAL = auto()
-    LOGICAL_SAMPLE_TO_UNIFORMSAMPLE = auto()
-    LOGICAL_GET_TO_SEQSCAN = auto()
-    LOGICAL_DERIVED_GET_TO_PHYSICAL = auto()
-    LOGICAL_LATERAL_JOIN_TO_PHYSICAL = auto()
-    LOGICAL_JOIN_TO_PHYSICAL_HASH_JOIN = auto()
-    LOGICAL_FUNCTION_SCAN_TO_PHYSICAL = auto()
-    LOGICAL_FILTER_TO_PHYSICAL = auto()
-    LOGICAL_PROJECT_TO_PHYSICAL = auto()
-    LOGICAL_SHOW_TO_PHYSICAL = auto()
-    LOGICAL_DROP_UDF_TO_PHYSICAL = auto()
-    IMPLEMENTATION_DELIMETER = auto()
-
-    # TRANSFORMATION RULES (LOGICAL -> LOGICAL)
-    LOGICAL_INNER_JOIN_COMMUTATIVITY = auto()
-
-    # REWRITE RULES
-    EMBED_FILTER_INTO_GET = auto()
-    EMBED_PROJECT_INTO_GET = auto()
-    EMBED_FILTER_INTO_DERIVED_GET = auto()
-    EMBED_PROJECT_INTO_DERIVED_GET = auto()
-    PUSHDOWN_FILTER_THROUGH_SAMPLE = auto()
-    PUSHDOWN_PROJECT_THROUGH_SAMPLE = auto()
-    PUSHDOWN_FILTER_THROUGH_JOIN = auto()
-
-
-class Rule(ABC):
-    """Base class to define any optimization rule
-
-    Arguments:
-        rule_type(RuleType): type of the rule, can be rewrite,
-            logical->physical
-        pattern: the match pattern for the rule
-    """
-
-    def __init__(self, rule_type: RuleType, pattern=None):
-        self._pattern = pattern
-        self._rule_type = rule_type
-
-    @property
-    def rule_type(self):
-        return self._rule_type
-
-    @property
-    def pattern(self):
-        return self._pattern
-
-    @pattern.setter
-    def pattern(self, pattern):
-        self._pattern = pattern
-
-    def top_match(self, opr: Operator) -> bool:
-        return opr.opr_type == self.pattern.opr_type
-
-    @abstractmethod
-    def promise(self) -> int:
-        raise NotImplementedError
-
-    @abstractmethod
-    def check(self, before: Operator, context: OptimizerContext) -> bool:
-        """Check whether the rule is applicable for the input_expr
-
-        Args:
-            before (Operator): the before operator expression
-
-        Returns:
-            bool: If the rule is applicable, return true, else false
-        """
-        raise NotImplementedError
-
-    @abstractmethod
-    def apply(self, before: Operator) -> Operator:
-        """Transform the before expression to the after expression
-
-        Args:
-            before (Operator): the before expression
-
-        Returns:
-            Operator: the transformed expression
-        """
-        raise NotImplementedError
-
-
 ##############################################
 # REWRITE RULES START
 
@@ -274,6 +124,7 @@ class EmbedFilterIntoGet(Rule):
                 alias=lget.alias,
                 predicate=pushdown_pred,
                 target_list=lget.target_list,
+                sampling_rate=lget.sampling_rate,
                 children=lget.children,
             )
             if unsupported_pred:
@@ -285,6 +136,37 @@ class EmbedFilterIntoGet(Rule):
             return before
 
 
+class EmbedSampleIntoGet(Rule):
+    def __init__(self):
+        pattern = Pattern(OperatorType.LOGICALSAMPLE)
+        pattern.append_child(Pattern(OperatorType.LOGICALGET))
+        super().__init__(RuleType.EMBED_SAMPLE_INTO_GET, pattern)
+
+    def promise(self):
+        return Promise.EMBED_SAMPLE_INTO_GET
+
+    def check(self, before: LogicalSample, context: OptimizerContext):
+        # System supports sample pushdown only while reading video data
+        lget: LogicalGet = before.children[0]
+        if lget.dataset_metadata.is_video:
+            return True
+        return False
+
+    def apply(self, before: LogicalSample, context: OptimizerContext):
+        sample_freq = before.sample_freq.value
+        lget: LogicalGet = before.children[0]
+        new_get_opr = LogicalGet(
+            lget.video,
+            lget.dataset_metadata,
+            alias=lget.alias,
+            predicate=lget.predicate,
+            target_list=lget.target_list,
+            sampling_rate=sample_freq,
+            children=lget.children,
+        )
+        return new_get_opr
+
+
 class EmbedProjectIntoGet(Rule):
     def __init__(self):
         pattern = Pattern(OperatorType.LOGICALPROJECT)
@@ -307,6 +189,7 @@ class EmbedProjectIntoGet(Rule):
             alias=lget.alias,
             predicate=lget.predicate,
             target_list=target_list,
+            sampling_rate=lget.sampling_rate,
             children=lget.children,
         )
 
@@ -370,56 +253,6 @@ class EmbedProjectIntoDerivedGet(Rule):
         return new_opr
 
 
-class PushdownFilterThroughSample(Rule):
-    def __init__(self):
-        pattern = Pattern(OperatorType.LOGICALFILTER)
-        pattern_sample = Pattern(OperatorType.LOGICALSAMPLE)
-        pattern_sample.append_child(Pattern(OperatorType.LOGICALGET))
-        pattern.append_child(pattern_sample)
-        super().__init__(RuleType.PUSHDOWN_FILTER_THROUGH_SAMPLE, pattern)
-
-    def promise(self):
-        return Promise.PUSHDOWN_FILTER_THROUGH_SAMPLE
-
-    def check(self, before: Operator, context: OptimizerContext):
-        # nothing else to check if logical match found return true
-        return True
-
-    def apply(self, before: LogicalFilter, context: OptimizerContext):
-        sample = before.children[0]
-        logical_get = sample.children[0]
-        new_filter = LogicalFilter(before.predicate)
-        new_filter.append_child(logical_get)
-        sample.clear_children()
-        sample.append_child(new_filter)
-        return sample
-
-
-class PushdownProjectThroughSample(Rule):
-    def __init__(self):
-        pattern = Pattern(OperatorType.LOGICALPROJECT)
-        pattern_sample = Pattern(OperatorType.LOGICALSAMPLE)
-        pattern_sample.append_child(Pattern(OperatorType.LOGICALGET))
-        pattern.append_child(pattern_sample)
-        super().__init__(RuleType.PUSHDOWN_PROJECT_THROUGH_SAMPLE, pattern)
-
-    def promise(self):
-        return Promise.PUSHDOWN_PROJECT_THROUGH_SAMPLE
-
-    def check(self, before: Operator, context: OptimizerContext):
-        # nothing else to check if logical match found return true
-        return True
-
-    def apply(self, before: LogicalProject, context: OptimizerContext):
-        sample = before.children[0]
-        logical_get = sample.children[0]
-        new_project = LogicalProject(before.target_list)
-        new_project.append_child(logical_get)
-        sample.clear_children()
-        sample.append_child(new_project)
-        return sample
-
-
 # Join Queries
 class PushDownFilterThroughJoin(Rule):
     def __init__(self):
@@ -717,6 +550,7 @@ class LogicalGetToSeqScan(Rule):
                 before.dataset_metadata,
                 batch_mem_size=batch_mem_size,
                 predicate=before.predicate,
+                sampling_rate=before.sampling_rate,
             )
         )
         return after
@@ -780,6 +614,25 @@ class LogicalUnionToPhysical(Rule):
         return after
 
 
+class LogicalGroupByToPhysical(Rule):
+    def __init__(self):
+        pattern = Pattern(OperatorType.LOGICALGROUPBY)
+        pattern.append_child(Pattern(OperatorType.DUMMY))
+        super().__init__(RuleType.LOGICAL_GROUPBY_TO_PHYSICAL, pattern)
+
+    def promise(self):
+        return Promise.LOGICAL_GROUPBY_TO_PHYSICAL
+
+    def check(self, before: Operator, context: OptimizerContext):
+        return True
+
+    def apply(self, before: LogicalGroupBy, context: OptimizerContext):
+        after = GroupByPlan(before.groupby_clause)
+        for child in before.children:
+            after.append_child(child)
+        return after
+
+
 class LogicalOrderByToPhysical(Rule):
     def __init__(self):
         pattern = Pattern(OperatorType.LOGICALORDERBY)
@@ -977,72 +830,24 @@ class LogicalShowToPhysical(Rule):
         return after
 
 
+class LogicalExplainToPhysical(Rule):
+    def __init__(self):
+        pattern = Pattern(OperatorType.LOGICALEXPLAIN)
+        pattern.append_child(Pattern(OperatorType.DUMMY))
+        super().__init__(RuleType.LOGICAL_EXPLAIN_TO_PHYSICAL, pattern)
+
+    def promise(self):
+        return Promise.LOGICAL_EXPLAIN_TO_PHYSICAL
+
+    def check(self, grp_id: int, context: OptimizerContext):
+        return True
+
+    def apply(self, before: LogicalExplain, context: OptimizerContext):
+        after = ExplainPlan(before.explainable_opr)
+        for child in before.children:
+            after.append_child(child)
+        return after
+
+
 # IMPLEMENTATION RULES END
 ##############################################
-
-
-class RulesManager:
-    """Singelton class to manage all the rules in our system"""
-
-    _instance = None
-
-    def __new__(cls):
-        if cls._instance is None:
-            cls._instance = super(RulesManager, cls).__new__(cls)
-        return cls._instance
-
-    def __init__(self):
-        self._logical_rules = [LogicalInnerJoinCommutativity()]
-
-        self._rewrite_rules = [
-            EmbedFilterIntoGet(),
-            # EmbedFilterIntoDerivedGet(),
-            PushdownFilterThroughSample(),
-            EmbedProjectIntoGet(),
-            # EmbedProjectIntoDerivedGet(),
-            PushdownProjectThroughSample(),
-            PushDownFilterThroughJoin(),
-        ]
-
-        self._implementation_rules = [
-            LogicalCreateToPhysical(),
-            LogicalRenameToPhysical(),
-            LogicalDropToPhysical(),
-            LogicalCreateUDFToPhysical(),
-            LogicalDropUDFToPhysical(),
-            LogicalInsertToPhysical(),
-            LogicalLoadToPhysical(),
-            LogicalUploadToPhysical(),
-            LogicalSampleToUniformSample(),
-            LogicalGetToSeqScan(),
-            LogicalDerivedGetToPhysical(),
-            LogicalUnionToPhysical(),
-            LogicalOrderByToPhysical(),
-            LogicalLimitToPhysical(),
-            LogicalLateralJoinToPhysical(),
-            LogicalJoinToPhysicalHashJoin(),
-            LogicalFunctionScanToPhysical(),
-            LogicalCreateMaterializedViewToPhysical(),
-            LogicalFilterToPhysical(),
-            LogicalProjectToPhysical(),
-            LogicalShowToPhysical(),
-        ]
-        self._all_rules = (
-            self._rewrite_rules + self._logical_rules + self._implementation_rules
-        )
-
-    @property
-    def rewrite_rules(self):
-        return self._rewrite_rules
-
-    @property
-    def implementation_rules(self):
-        return self._implementation_rules
-
-    @property
-    def logical_rules(self):
-        return self._logical_rules
-
-    @property
-    def all_rules(self):
-        return self._all_rules
