@@ -19,9 +19,11 @@ from eva.optimizer.operators import (
     LogicalCreateUDF,
     LogicalDrop,
     LogicalDropUDF,
+    LogicalExplain,
     LogicalFilter,
     LogicalFunctionScan,
     LogicalGet,
+    LogicalGroupBy,
     LogicalJoin,
     LogicalLimit,
     LogicalLoadData,
@@ -40,6 +42,7 @@ from eva.parser.create_statement import CreateTableStatement
 from eva.parser.create_udf_statement import CreateUDFStatement
 from eva.parser.drop_statement import DropTableStatement
 from eva.parser.drop_udf_statement import DropUDFStatement
+from eva.parser.explain_statement import ExplainStatement
 from eva.parser.insert_statement import InsertTableStatement
 from eva.parser.load_statement import LoadDataStatement
 from eva.parser.rename_statement import RenameTableStatement
@@ -117,16 +120,20 @@ class StatementToPlanConvertor:
         if predicate is not None:
             self._visit_select_predicate(predicate)
 
+        # union
+        if statement.union_link is not None:
+            self._visit_union(statement.union_link, statement.union_all)
+
+        # TODO ACTION: Group By
+        if statement.groupby_clause is not None:
+            self._visit_groupby(statement.groupby_clause)
+
         # Projection operator
         select_columns = statement.target_list
 
         if select_columns is not None:
             self._visit_projection(select_columns)
 
-        # union
-        if statement.union_link is not None:
-            self._visit_union(statement.union_link, statement.union_all)
-
         if statement.orderby_list is not None:
             self._visit_orderby(statement.orderby_list)
 
@@ -138,6 +145,11 @@ class StatementToPlanConvertor:
         sample_opr.append_child(self._plan)
         self._plan = sample_opr
 
+    def _visit_groupby(self, groupby_clause):
+        groupby_opr = LogicalGroupBy(groupby_clause)
+        groupby_opr.append_child(self._plan)
+        self._plan = groupby_opr
+
     def _visit_orderby(self, orderby_list):
         # orderby_list structure: List[(TupleValueExpression, EnumInt), ...]
         orderby_opr = LogicalOrderBy(orderby_list)
@@ -292,6 +304,10 @@ class StatementToPlanConvertor:
         show_opr = LogicalShow(statement.show_type)
         self._plan = show_opr
 
+    def visit_explain(self, statement: ExplainStatement):
+        explain_opr = LogicalExplain([self.visit(statement.explainable_stmt)])
+        self._plan = explain_opr
+
     def visit(self, statement: AbstractStatement):
         """Based on the instance of the statement the corresponding
            visit is called.
@@ -322,6 +338,8 @@ class StatementToPlanConvertor:
             self.visit_materialized_view(statement)
         elif isinstance(statement, ShowStatement):
             self.visit_show(statement)
+        elif isinstance(statement, ExplainStatement):
+            self.visit_explain(statement)
         return self._plan
 
     @property
