@@ -14,6 +14,8 @@
 # limitations under the License.
 from eva.parser.evaql.evaql_parser import evaql_parser
 from eva.parser.evaql.evaql_parserVisitor import evaql_parserVisitor
+from eva.parser.table_ref import TableRef
+from eva.parser.types import FileFormatType
 from eva.parser.upload_statement import UploadStatement
 
 
@@ -21,5 +23,20 @@ class Upload(evaql_parserVisitor):
     def visitUploadStatement(self, ctx: evaql_parser.UploadStatementContext):
         srv_path = self.visit(ctx.fileName()).value
         video_blob = self.visit(ctx.videoBlob()).value
-        stmt = UploadStatement(srv_path, video_blob)
+        table = TableRef(self.visit(ctx.tableName()))
+
+        # Set default for file_format as Video
+        file_format = FileFormatType.VIDEO
+        file_options = {}
+        file_options["file_format"] = file_format
+
+        if ctx.fileOptions():
+            file_options = self.visit(ctx.fileOptions())
+
+        # set default for column_list as None
+        column_list = None
+        if ctx.uidList():
+            column_list = self.visit(ctx.uidList())
+
+        stmt = UploadStatement(srv_path, video_blob, table, column_list, file_options)
         return stmt
