@@ -53,6 +53,13 @@ class CreatePlan(AbstractPlan):
     def column_list(self):
         return self._column_list
 
+    def __str__(self):
+        return "CreatePlan(table_ref={}, \
+            column_list={}, \
+            if_not_exists={})".format(
+            self._table_ref, self._column_list, self._if_not_exists
+        )
+
     def __hash__(self) -> int:
         return hash(
             (
