@@ -40,5 +40,8 @@ class LimitPlan(AbstractPlan):
     def limit_value(self):
         return self._limit_count.value
 
+    def __str__(self):
+        return "LimitPlan(limit_count={})".format(self._limit_count)
+
     def __hash__(self) -> int:
         return hash((super().__hash__(), self._limit_count))
