@@ -45,5 +45,12 @@ class SeqScanPlan(AbstractScan):
     def columns(self):
         return self._columns
 
+    def __str__(self):
+        return "SeqScanPlan(predicate={}, \
+            columns={}, \
+            alias={})".format(
+            self._predicate, self._columns, self.alias
+        )
+
     def __hash__(self) -> int:
         return hash((super().__hash__(), tuple(self.columns or []), self.alias))
