@@ -26,5 +26,8 @@ class ShowInfoPlan(AbstractPlan):
     def show_type(self):
         return self._show_type
 
+    def __str__(self):
+        return "ShowUDFPlan" if self._show_type == ShowType.UDF else "ShowTablePlan"
+
     def __hash__(self) -> int:
         return hash((super().__hash__(), self.show_type))
