@@ -29,6 +29,7 @@ class PlanOprType(Enum):
     LOAD_DATA = auto()
     UPLOAD = auto()
     UNION = auto()
+    GROUP_BY = auto()
     ORDER_BY = auto()
     LIMIT = auto()
     SAMPLE = auto()
@@ -37,8 +38,10 @@ class PlanOprType(Enum):
     LATERAL_JOIN = auto()
     HASH_BUILD = auto()
     CREATE_MATERIALIZED_VIEW = auto()
+    EXCHANGE = auto()
     PREDICATE_FILTER = auto()
     PROJECT = auto()
     SHOW_INFO = auto()
     DROP_UDF = auto()
+    EXPLAIN = auto()
     # add other types
