@@ -14,7 +14,10 @@
 # limitations under the License.
 import asyncio
 import socket
+import struct
+from typing import Any
 
+from eva.utils.generic_utils import PickleSerializer
 from eva.utils.logging_manager import logger
 
 
@@ -79,3 +82,10 @@ def set_socket_io_timeouts(transport, seconds, useconds=0):
         return True
     except OSError:
         return False
+
+
+def serialize_message(message: Any):
+    pickled_message = PickleSerializer.serialize(message)
+    header = struct.pack("!Q", len(pickled_message))
+    data = header + pickled_message
+    return data
