@@ -20,25 +20,28 @@ import torch
 from torch import Tensor
 from torchvision import models
 
-from eva.udfs.pytorch_abstract_udf import PytorchAbstractClassifierUDF
+from eva.udfs.abstract.pytorch_abstract_udf import PytorchAbstractClassifierUDF
 
 
 class FeatureExtractor(PytorchAbstractClassifierUDF):
     """ """
 
-    def __init__(self):
-        super().__init__()
+    def setup(self):
         self.model = models.resnet50(pretrained=True, progress=False)
         for param in self.model.parameters():
             param.requires_grad = False
         self.model.fc = torch.nn.Identity()
         self.model.eval()
 
+    @property
+    def name(self) -> str:
+        return "FeatureExtractor"
+
     @property
     def labels(self) -> List[str]:
         return []
 
-    def _get_predictions(self, frames: Tensor) -> pd.DataFrame:
+    def forward(self, frames: Tensor) -> pd.DataFrame:
         """
         Performs feature extraction on input frames
         Arguments:
