@@ -28,7 +28,10 @@ from eva.parser.types import FileFormatType
 
 class LoadExecutorTest(unittest.TestCase):
     @patch("eva.executor.load_video_executor.VideoStorageEngine.create")
-    def test_should_call_opencv_reader_and_storage_engine(self, create_mock):
+    @patch("eva.executor.load_video_executor.VideoStorageEngine.write")
+    def test_should_call_opencv_reader_and_storage_engine(
+        self, write_mock, create_mock
+    ):
         file_path = "video"
         table_metainfo = "info"
         batch_mem_size = 3000
@@ -49,14 +52,18 @@ class LoadExecutorTest(unittest.TestCase):
         with patch.object(Path, "exists") as mock_exists:
             mock_exists.return_value = True
             batch = next(load_executor.exec())
-            create_mock.assert_called_once_with(table_metainfo, file_path)
+            create_mock.assert_called_once_with(table_metainfo, if_not_exists=True)
+            write_mock.assert_called_once_with(
+                table_metainfo, Batch(pd.DataFrame([{"video_file_path": file_path}]))
+            )
             expected = Batch(
                 pd.DataFrame([{f"Video successfully added at location: {file_path}"}])
             )
             self.assertEqual(batch, expected)
 
     @patch("eva.executor.load_video_executor.VideoStorageEngine.create")
-    def test_should_search_in_upload_directory(self, create_mock):
+    @patch("eva.executor.load_video_executor.VideoStorageEngine.write")
+    def test_should_search_in_upload_directory(self, write_mock, create_mock):
         self.upload_path = Path(
             ConfigurationManager().get_value("storage", "upload_dir")
         )
@@ -81,14 +88,19 @@ class LoadExecutorTest(unittest.TestCase):
             mock_exists.side_effect = [False, True]
             batch = next(load_executor.exec())
             location = self.upload_path / file_path
-            create_mock.assert_called_once_with(table_metainfo, location)
+            create_mock.assert_called_once_with(table_metainfo, if_not_exists=True)
+            write_mock.assert_called_once_with(
+                table_metainfo,
+                Batch(pd.DataFrame([{"video_file_path": str(location)}])),
+            )
             expected = Batch(
                 pd.DataFrame([{f"Video successfully added at location: {location}"}])
             )
             self.assertEqual(batch, expected)
 
     @patch("eva.executor.load_video_executor.VideoStorageEngine.create")
-    def test_should_fail_to_find_file(self, create_mock):
+    @patch("eva.executor.load_video_executor.VideoStorageEngine.write")
+    def test_should_fail_to_find_file(self, write_mock, create_mock):
         file_path = "video"
         table_metainfo = "info"
         batch_mem_size = 3000
