@@ -14,6 +14,7 @@
 # limitations under the License.
 import unittest
 from test.util import (
+    create_dummy_4d_batches,
     create_dummy_batches,
     create_sample_video,
     create_table,
@@ -49,6 +50,12 @@ class SelectExecutorTest(unittest.TestCase):
     @classmethod
     def tearDownClass(cls):
         file_remove("dummy.avi")
+        drop_query = """DROP TABLE table1;"""
+        execute_query_fetch_all(drop_query)
+        drop_query = """DROP TABLE table2;"""
+        execute_query_fetch_all(drop_query)
+        drop_query = """DROP TABLE table3;"""
+        execute_query_fetch_all(drop_query)
 
     def test_sort_on_nonprojected_column(self):
         """This tests doing an order by on a column
@@ -130,7 +137,6 @@ class SelectExecutorTest(unittest.TestCase):
         select_query = """SELECT * FROM MyVideo JOIN LATERAL
                           FastRCNNObjectDetector(data);"""
         actual_batch = execute_query_fetch_all(select_query)
-        print(actual_batch)
         self.assertEqual(actual_batch.frames.columns, ["myvideo.id"])
 
     def test_should_load_and_select_real_video_in_table(self):
@@ -246,7 +252,119 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(len(actual_batch), len(expected_batch[0]))
         # Since frames are fetched in random order, this test might be flaky
         # Disabling it for time being
-        # self.assertEqual(actual_batch, expected_batch[0])
+        self.assertEqual(actual_batch, expected_batch[0])
+
+    def test_select_and_groupby(self):
+        # groupby and orderby together not tested because groupby
+        # only applies to video data which is already sorted
+        segment_size = 3
+        select_query = (
+            "SELECT FIRST(id), SEGMENT(data) FROM MyVideo GROUP BY '{}f';".format(
+                segment_size
+            )
+        )
+        actual_batch = execute_query_fetch_all(select_query)
+        actual_batch.sort()
+        ids = np.arange(NUM_FRAMES)
+        segments = [ids[i : i + segment_size] for i in range(0, len(ids), segment_size)]
+        segments = [i for i in segments if len(i) == segment_size]
+        expected_batch = list(create_dummy_4d_batches(filters=segments))[0]
+        self.assertEqual(len(actual_batch), len(expected_batch))
+        self.assertEqual(
+            actual_batch,
+            expected_batch.project(["myvideo.id", "myvideo.data"]),
+        )
+
+    def test_select_and_groupby_with_last(self):
+        # groupby and orderby together not tested because groupby
+        # only applies to video data which is already sorted
+        segment_size = 3
+        select_query = (
+            "SELECT LAST(id), SEGMENT(data) FROM MyVideo GROUP BY '{}f';".format(
+                segment_size
+            )
+        )
+        actual_batch = execute_query_fetch_all(select_query)
+        actual_batch.sort()
+        ids = np.arange(NUM_FRAMES)
+        segments = [ids[i : i + segment_size] for i in range(0, len(ids), segment_size)]
+        segments = [i for i in segments if len(i) == segment_size]
+        expected_batch = list(
+            create_dummy_4d_batches(filters=segments, start_id=segment_size - 1)
+        )[0]
+        self.assertEqual(len(actual_batch), len(expected_batch))
+        self.assertEqual(
+            actual_batch,
+            expected_batch.project(["myvideo.id", "myvideo.data"]),
+        )
+
+    def test_select_and_groupby_should_fail_with_incorrect_pattern(self):
+        segment_size = "4a"
+        select_query = (
+            "SELECT FIRST(id), SEGMENT(data) FROM MyVideo GROUP BY '{}f';".format(
+                segment_size
+            )
+        )
+        self.assertRaises(BinderError, execute_query_fetch_all, select_query)
+
+    def test_select_and_groupby_should_fail_with_seconds(self):
+        segment_size = 4
+        select_query = (
+            "SELECT FIRST(id), SEGMENT(data) FROM MyVideo GROUP BY '{}s';".format(
+                segment_size
+            )
+        )
+        self.assertRaises(BinderError, execute_query_fetch_all, select_query)
+
+    def test_select_and_groupby_should_fail_with_non_video_table(self):
+        segment_size = 4
+        select_query = "SELECT FIRST(a1) FROM table1 GROUP BY '{}f';".format(
+            segment_size
+        )
+        self.assertRaises(BinderError, execute_query_fetch_all, select_query)
+
+    def test_select_and_groupby_with_sample(self):
+        # TODO ACTION: groupby and orderby together not tested because groupby
+        # only applies to video data which is already sorted
+        segment_size = 2
+        sampling_rate = 2
+        select_query = "SELECT FIRST(id), SEGMENT(data) FROM MyVideo SAMPLE {} GROUP BY '{}f';".format(
+            sampling_rate, segment_size
+        )
+        actual_batch = execute_query_fetch_all(select_query)
+        actual_batch.sort()
+        ids = np.arange(0, NUM_FRAMES, sampling_rate)
+
+        segments = [ids[i : i + segment_size] for i in range(0, len(ids), segment_size)]
+        segments = [i for i in segments if len(i) == segment_size]
+        expected_batch = list(create_dummy_4d_batches(filters=segments))[0]
+        self.assertEqual(len(actual_batch), len(expected_batch))
+        self.assertEqual(
+            actual_batch,
+            expected_batch.project(["myvideo.id", "myvideo.data"]),
+        )
+
+    def test_select_and_sample_with_predicate(self):
+        select_query = (
+            "SELECT name, id,data FROM MyVideo SAMPLE 2 WHERE id > 5 ORDER BY id;"
+        )
+        actual_batch = execute_query_fetch_all(select_query)
+        expected_batch = list(create_dummy_batches(filters=range(6, NUM_FRAMES, 2)))
+        self.assertEqual(actual_batch, expected_batch[0])
+
+        select_query = (
+            "SELECT name, id,data FROM MyVideo SAMPLE 4 WHERE id > 2 ORDER BY id;"
+        )
+        actual_batch = execute_query_fetch_all(select_query)
+        print(actual_batch)
+        expected_batch = list(create_dummy_batches(filters=range(4, NUM_FRAMES, 4)))
+        self.assertEqual(actual_batch, expected_batch[0])
+
+        select_query = "SELECT name, id,data FROM MyVideo SAMPLE 2 WHERE id > 2 AND id < 8 ORDER BY id;"
+        actual_batch = execute_query_fetch_all(select_query)
+        print(actual_batch)
+        expected_batch = list(create_dummy_batches(filters=range(4, 8, 2)))
+        self.assertEqual(actual_batch, expected_batch[0])
 
     @pytest.mark.torchtest
     def test_lateral_join(self):
@@ -297,6 +415,36 @@ class SelectExecutorTest(unittest.TestCase):
 
         self.assertEqual(unnest_batch, expected)
 
+    def test_lateral_join_with_unnest_and_sample(self):
+        query = """SELECT id, label
+                  FROM MyVideo SAMPLE 2 JOIN LATERAL
+                    UNNEST(DummyMultiObjectDetector(data).labels) AS T(label)
+                  WHERE id < 10 ORDER BY id;"""
+        unnest_batch = execute_query_fetch_all(query)
+        expected = Batch(
+            pd.DataFrame(
+                {
+                    "myvideo.id": np.array([0, 0, 2, 2, 4, 4, 6, 6, 8, 8]),
+                    "T.label": np.array(
+                        [
+                            "person",
+                            "person",
+                            "car",
+                            "car",
+                            "bicycle",
+                            "bicycle",
+                            "person",
+                            "person",
+                            "car",
+                            "car",
+                        ]
+                    ),
+                }
+            )
+        )
+        self.assertEqual(len(unnest_batch), 10)
+        self.assertEqual(unnest_batch, expected)
+
     def test_lateral_join_with_unnest_on_subset_of_outputs(self):
         query = """SELECT id, label
                   FROM MyVideo JOIN LATERAL
@@ -428,7 +576,3 @@ class SelectExecutorTest(unittest.TestCase):
                 expected_batch.sort_orderby(["table1.a0"]),
                 actual_batch.sort_orderby(["table1.a0"]),
             )
-
-
-if __name__ == "__main__":
-    unittest.main()
